==> ose-baremetal-operator-container-v4.6.0-202101160045.p0.tar.gz: ose-baremetal-operator-container-v4.6.0-202101160045.p0/pkg/bmc/redfish_virtualmedia.go <==
package bmc

import (
	"net/url"
)

func init() {
	schemes := []string{"http", "https"}
	registerFactory("redfish-virtualmedia", newRedfishVirtualMediaAccessDetails, schemes)
	registerFactory("ilo5-virtualmedia", newRedfishVirtualMediaAccessDetails, schemes)
}

func newRedfishVirtualMediaAccessDetails(parsedURL *url.URL, disableCertificateVerification bool) (AccessDetails, error) {
	return &redfishVirtualMediaAccessDetails{
		bmcType:                        parsedURL.Scheme,
		host:                           parsedURL.Host,
		path:                           parsedURL.Path,
		disableCertificateVerification: disableCertificateVerification,
	}, nil
}

type redfishVirtualMediaAccessDetails struct {
	bmcType                        string
	host                           string
	path                           string
	disableCertificateVerification bool
}

func (a *redfishVirtualMediaAccessDetails) Type() string {
	return a.bmcType
}

// NeedsMAC returns true when the host is going to need a separate
// port created rather than having it discovered.
func (a *redfishVirtualMediaAccessDetails) NeedsMAC() bool {
	// For the inspection to work, we need a MAC address
	// https://github.com/metal3-io/baremetal-operator/pull/284#discussion_r317579040
	return true
}

func (a *redfishVirtualMediaAccessDetails) Driver() string {
	return "redfish"
}

func (a *redfishVirtualMediaAccessDetails) DisableCertificateVerification() bool {
	return a.disableCertificateVerification
}

// DriverInfo returns a data structure to pass as the DriverInfo
// parameter when creating a node in Ironic. The structure is
// pre-populated with the access information, and the caller is
// expected to add any other information that might be needed (such as
// the kernel and ramdisk locations).
func (a *redfishVirtualMediaAccessDetails) DriverInfo(bmcCreds Credentials) map[string]interface{} {
	result := map[string]interface{}{
		"redfish_system_id": a.path,
		"redfish_username":  bmcCreds.Username,
		"redfish_password":  bmcCreds.Password,
		"redfish_address":   getRedfishAddress(a.bmcType, a.host),
	}

	if a.disableCertificateVerification {
		result["redfish_verify_ca"] = false
	}

	return result
}

func (a *redfishVirtualMediaAccessDetails) BootInterface() string {
	return "redfish-virtual-media"
}

func (a *redfishVirtualMediaAccessDetails) ManagementInterface() string {
	return ""
}

func (a *redfishVirtualMediaAccessDetails) PowerInterface() string {
	return ""
}

func (a *redfishVirtualMediaAccessDetails) RAIDInterface() string {
	return ""
}

func (a *redfishVirtualMediaAccessDetails) VendorInterface() string {
	return ""
}

==> ose-baremetal-operator-container-v4.7.0-202104030128.p0.tar.gz: ose-baremetal-operator-container-v4.7.0-202104030128.p0/pkg/bmc/redfish_virtualmedia.go <==
package bmc

import (
	"net/url"
)

func init() {
	schemes := []string{"http", "https"}
	RegisterFactory("redfish-virtualmedia", newRedfishVirtualMediaAccessDetails, schemes)
	RegisterFactory("ilo5-virtualmedia", newRedfishVirtualMediaAccessDetails, schemes)
}

func newRedfishVirtualMediaAccessDetails(parsedURL *url.URL, disableCertificateVerification bool) (AccessDetails, error) {
	return &redfishVirtualMediaAccessDetails{
		bmcType:                        parsedURL.Scheme,
		host:                           parsedURL.Host,
		path:                           parsedURL.Path,
		disableCertificateVerification: disableCertificateVerification,
	}, nil
}

type redfishVirtualMediaAccessDetails struct {
	bmcType                        string
	host                           string
	path                           string
	disableCertificateVerification bool
}

func (a *redfishVirtualMediaAccessDetails) Type() string {
	return a.bmcType
}

// NeedsMAC returns true when the host is going to need a separate
// port created rather than having it discovered.
func (a *redfishVirtualMediaAccessDetails) NeedsMAC() bool {
	// For the inspection to work, we need a MAC address
	// https://github.com/metal3-io/baremetal-operator/pull/284#discussion_r317579040
	return true
}

func (a *redfishVirtualMediaAccessDetails) Driver() string {
	return "redfish"
}

func (a *redfishVirtualMediaAccessDetails) DisableCertificateVerification() bool {
	return a.disableCertificateVerification
}

// DriverInfo returns a data structure to pass as the DriverInfo
// parameter when creating a node in Ironic. The structure is
// pre-populated with the access information, and the caller is
// expected to add any other information that might be needed (such as
// the kernel and ramdisk locations).
func (a *redfishVirtualMediaAccessDetails) DriverInfo(bmcCreds Credentials) map[string]interface{} {
	result := map[string]interface{}{
		"redfish_system_id": a.path,
		"redfish_username":  bmcCreds.Username,
		"redfish_password":  bmcCreds.Password,
		"redfish_address":   getRedfishAddress(a.bmcType, a.host),
	}

	if a.disableCertificateVerification {
		result["redfish_verify_ca"] = false
	}

	return result
}

func (a *redfishVirtualMediaAccessDetails) BootInterface() string {
	return "redfish-virtual-media"
}

func (a *redfishVirtualMediaAccessDetails) ManagementInterface() string {
	return ""
}

func (a *redfishVirtualMediaAccessDetails) PowerInterface() string {
	return ""
}

func (a *redfishVirtualMediaAccessDetails) RAIDInterface() string {
	return ""
}

func (a *redfishVirtualMediaAccessDetails) VendorInterface() string {
	return ""
}
